@@ -14,9 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import socket
-from calculate.consolegui import qt
+from .. import qt
 
 from .more import LabelWordWrap, show_msg, get_icon
 
