@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 from .more import LabelWordWrap, show_msg, get_icon
 import datetime
 from calculate.lib.datavars import DataVars
