@@ -136,10 +136,10 @@ class ViewSessionInfo (qt.QWidget):
         self.setWindowIcon(get_icon("document-edit-verify"))
         self.setWindowTitle(_('Session information'))
 
-        self.move(window.geometry().x() + window.geometry().width() / 2 \
-                  - self.size().width() / 2, \
-                  window.geometry().y() + window.geometry().height() / 2 \
-                  - self.size().height() / 2)
+        self.move(int(window.geometry().x() + window.geometry().width() / 2 \
+                  - self.size().width() / 2), \
+                  int(window.geometry().y() + window.geometry().height() / 2 \
+                  - self.size().height() / 2))
 
     def clear_cache(self, client, sid):
         def wrapper():
